// nsIWebProgressListener implementation to monitor activity in the browser.
function WebProgressListener() {
}
WebProgressListener.prototype = {
  _requestsStarted: 0,
  _requestsFinished: 0,

  // We need to advertize that we support weak references.  This is done simply
  // by saying that we QI to nsISupportsWeakReference.  XPConnect will take
  // care of actually implementing that interface on our behalf.
  QueryInterface: function(iid) {
    if (iid.equals(Components.interfaces.nsIWebProgressListener) ||
        iid.equals(Components.interfaces.nsISupportsWeakReference) ||
        iid.equals(Components.interfaces.nsISupports))
      return this;
    
    throw Components.results.NS_ERROR_NO_INTERFACE;
  },

  // This method is called to indicate state changes.
  onStateChange: function(webProgress, request, stateFlags, status) {
    const WPL = Components.interfaces.nsIWebProgressListener;

    var progress = document.getElementById("progress");

    if (stateFlags & WPL.STATE_IS_REQUEST) {
      if (stateFlags & WPL.STATE_START) {
        this._requestsStarted++;
      } else if (stateFlags & WPL.STATE_STOP) {
        this._requestsFinished++;
      }
      if (this._requestsStarted > 1) {
        var value = (100 * this._requestsFinished) / this._requestsStarted;
        progress.setAttribute("mode", "determined");
        progress.setAttribute("value", value + "%");
      }
    }

    if (stateFlags & WPL.STATE_IS_NETWORK) {
      var stop = document.getElementById("stop");
      if (stateFlags & WPL.STATE_START) {
        //stop.setAttribute("disabled", false);
        //progress.setAttribute("style", "");
      } else if (stateFlags & WPL.STATE_STOP) {
        //stop.setAttribute("disabled", true);
        //progress.setAttribute("style", "display: none");
        progress.setAttribute("value", "0%");
        this.onStatusChange(webProgress, request, 0, "Done");
        this._requestsStarted = this._requestsFinished = 0;
      }
    }
  },

  // This method is called to indicate progress changes for the currently
  // loading page.
  onProgressChange: function(webProgress, request, curSelf, maxSelf,
                             curTotal, maxTotal) {
    if (this._requestsStarted == 1) {
      var progress = document.getElementById("progress");
      if (maxSelf == -1) {
        progress.setAttribute("mode", "undetermined");
      } else {
        progress.setAttribute("mode", "determined");
        progress.setAttribute("value", ((100 * curSelf) / maxSelf) + "%");
      }
    }
  },

  // This method is called to indicate a change to the current location.
  onLocationChange: function(webProgress, request, location) {
    var urlbar = document.getElementById("urlbar");
    urlbar.value = location.spec;

    var browser = document.getElementById("browser");
    var back = document.getElementById("back");
    var forward = document.getElementById("forward");

    back.setAttribute("disabled", !browser.canGoBack);
    forward.setAttribute("disabled", !browser.canGoForward);
  },

  // This method is called to indicate a status changes for the currently
  // loading page.  The message is already formatted for display.
  onStatusChange: function(webProgress, request, status, message) {
    var status = document.getElementById("status");
    status.setAttribute("value", message);
  },

  // This method is called when the security state of the browser changes.
  onSecurityChange: function(webProgress, request, state) {
    const WPL = Components.interfaces.nsIWebProgressListener;

    var sec = document.getElementById("security");

    if (state & WPL.STATE_IS_INSECURE) {
      sec.setAttribute("style", "display: none");
    } else {
      var level = "unknown";
      if (state & WPL.STATE_IS_SECURE) {
        if (state & WPL.STATE_SECURE_HIGH)
          level = "high";
        else if (state & WPL.STATE_SECURE_MED)
          level = "medium";
        else if (state & WPL.STATE_SECURE_LOW)
          level = "low";
      } else if (state & WPL_STATE_IS_BROKEN) {
        level = "mixed";
      }
      sec.setAttribute("style", "");
    }
  }
};
var listener;
var prefs = Components.classes["@mozilla.org/preferences-service;1"].
                    getService(Components.interfaces.nsIPrefBranch);

function go() {
  var urlbar = document.getElementById("urlbar");
  var browser = document.getElementById("browser");

  if (urlbar.value.split(" ")[1]){
      var myval = "http://www.google.com/search?&q=";
      browser.loadURI(myval.concat(urlbar.value), null, null);
  } else {
      browser.loadURI(urlbar.value, null, null);
  }
  zoom();
}

function goto(url) {
  var urlbar = document.getElementById("urlbar");
  if (url.value) {
    urlbar.value = url.value
    go()
  }
}

function addbookmark() {
  var list = prefs.getCharPref("lightbrowser.bookmarks");
  var urlbar = document.getElementById("urlbar");
  // TODO make sure we dont get double entries
  // add validation
  if (validate(urlbar.value)){
      if (!list) {
          newlist = urlbar.value;
      } else {
          newlist = list+','+urlbar.value;
      }
      prefs.setCharPref("lightbrowser.bookmarks", newlist);

      alert('Added '+urlbar.value+' to the bookmarks menu')
  } else {
      alert(urlbar.value+" is already bookmarked");
  }
}

function validate(url) {
  var list = prefs.getCharPref("lightbrowser.bookmarks").split(",");;
  for(i=0;i<list.length;i++) {
      if (url == list[i]) {
          return false;
      }
  }
  return true;
}
function refreshbookmarks() {
  var list = prefs.getCharPref("lightbrowser.bookmarks").split(',');
  var mymenu = document.getElementById("blist");

  while(mymenu.itemCount) {
      mymenu.removeItemAt(mymenu.itemCount - 1);
  }
  for(i=0;i<list.length;i++) {
      mymenu.appendItem(list[i], list[i]);
  }
}

function rembookmark() {
   var list = prefs.getCharPref("lightbrowser.bookmarks");
   window.openDialog("chrome://lightbrowser/content/lightbrowser_bm.xul", "lightbrowserbookmarks","chrome,close,titlebar,modal",list);
    refreshbookmarks();
}

function back() {
  var browser = document.getElementById("browser");
  browser.stop();
  browser.goBack();
}

function forward() {
  var browser = document.getElementById("browser");
  browser.stop();
  browser.goForward();
}

function reload() {
  var browser = document.getElementById("browser");
  browser.reload();
  zoom();
}

function stop() {
  var browser = document.getElementById("browser");
  browser.stop();

}

function search() {
  var browser = document.getElementById("browser");
  var urlbar = document.getElementById("urlbar");
  var newval = ("http://www.google.com/search?&q=");
  if (urlbar.value.search(newval)){
     go();
  } else {
     var searchval = newval.concat(urlbar.value);
     urlbar.value = searchval;
     go();
  }
}

function showPrefs () {
   var url = document.getElementById("urlbar").value;
   var zoom = prefs.getCharPref("lightbrowser.scale");
   window.openDialog("chrome://lightbrowser/content/lightbrowser_pref.xul", "lightbrowserprefs","chrome,close,modal,titlebar",url);
   var newzoom = prefs.getCharPref("lightbrowser.scale");
   if (zoom != newzoom) {
    go();
   }
}

function zoomin() {
   var zoom = prefs.getCharPref("lightbrowser.scale");
   var newzoom = parseInt(zoom)+1;
   if (newzoom > 5) {
       newzoom = 5;
   }
   prefs.setCharPref("lightbrowser.scale", newzoom);
   reload();
}

function zoomout() {
   var zoom = prefs.getCharPref("lightbrowser.scale");
   var newzoom = parseInt(zoom)-1;
   if (newzoom < -5) {
       newzoom = -5;
   }
   prefs.setCharPref("lightbrowser.scale", newzoom);
   reload();
}

function showConsole() {
  window.open("chrome://global/content/console.xul", "_blank",
    "chrome,extrachrome,menubar,resizable,scrollbars,status,toolbar");
}

function quit (aForceQuit)
{
  var appStartup = Components.classes['@mozilla.org/toolkit/app-startup;1'].
                    getService(Components.interfaces.nsIAppStartup);
  var quitSeverity = aForceQuit ?  Components.interfaces.nsIAppStartup.eForceQuit :
                                   Components.interfaces.nsIAppStartup.eAttemptQuit;
  appStartup.quit(quitSeverity);
}

function home() {
  var urlbar = document.getElementById("urlbar");
  homeurl = prefs.getCharPref("lightbrowser.home");
  urlbar.value = homeurl;
  go();
}

function zoom() {
  var zoom = prefs.getCharPref("lightbrowser.scale");
  var contentViewer = document.getElementById("browser").markupDocumentViewer;
  contentViewer.fullZoom = 1+(zoom*0.1);
}


function onload() {
  var urlbar = document.getElementById("urlbar");
  homeurl = prefs.getCharPref("lightbrowser.home");
  urlbar.value = homeurl;

  listener = new WebProgressListener();

  var browser = document.getElementById("browser");
  browser.addProgressListener(listener,
    Components.interfaces.nsIWebProgress.NOTIFY_ALL);
  go();

}

//showConsole();
addEventListener("load", onload, false);
